API Reference
=============

This section contains the complete API documentation for the Gecko IoT Client.

.. currentmodule:: gecko_iot_client

Main Client
-----------

.. automodule:: gecko_iot_client
   :members:
   :undoc-members:
   :show-inheritance:

Models Package
--------------

.. automodule:: gecko_iot_client.models
   :members:
   :undoc-members:
   :show-inheritance:
   :exclude-members: AbstractZone, ZoneType, TemperatureControlZone, FlowZone, LightingZone, EventChannel, EventEmitter, ConnectivityStatus, OperationMode, OperationModeStatus

Zone Types
~~~~~~~~~~

.. automodule:: gecko_iot_client.models.abstract_zone
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: gecko_iot_client.models.temperature_control_zone
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: gecko_iot_client.models.flow_zone
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: gecko_iot_client.models.lighting_zone
   :members:
   :undoc-members:
   :show-inheritance:

Configuration and State Management
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: gecko_iot_client.models.zone_parser
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: gecko_iot_client.models.operation_mode
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: gecko_iot_client.models.connectivity
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: gecko_iot_client.models.events
   :members:
   :undoc-members:
   :show-inheritance:

Transporters Package
--------------------

.. automodule:: gecko_iot_client.transporters
   :members:
   :undoc-members:
   :show-inheritance:

MQTT Transport
~~~~~~~~~~~~~~

.. automodule:: gecko_iot_client.transporters.mqtt
   :members:
   :undoc-members:
   :show-inheritance:

Connection Management
~~~~~~~~~~~~~~~~~~~~~

.. automodule:: gecko_iot_client.transporters.connection_state
   :members:
   :undoc-members:
   :show-inheritance:

.. automodule:: gecko_iot_client.transporters.token_manager
   :members:
   :undoc-members:
   :show-inheritance:

Configuration and Logging
~~~~~~~~~~~~~~~~~~~~~~~~~~

.. automodule:: gecko_iot_client.transporters.logging_config
   :members:
   :undoc-members:
   :show-inheritance:

Exceptions
~~~~~~~~~~

.. automodule:: gecko_iot_client.transporters.exceptions
   :members:
   :undoc-members:
   :show-inheritance: